@@ -9,7 +9,7 @@ RibDif2 contains the following moduels:
 """
 __authors__ = "Robert Murphy"
 __licence__ = "GPL-3.0"
-__version__ = (2, 0, 0)
+__version__ = (1, 1, 0)
 
 
 # Try on python v3.5
@@ -18,5 +18,5 @@ if _sys.version_info[:2] < (3, 5):
     raise ImportError('Python version must be >= 3.5')
     
 
-from . import ngd.download
+from . import ngd_download
 from . import barrnap_run
\ No newline at end of file
