@@ -1,4 +1,4 @@
-# -*- coding: utf-8 -*-
+#!/usr/bin/env python3
 import ncbi_genome_download as ngd
 from pathlib import Path
 
@@ -29,11 +29,7 @@ def genome_download(genus, outdir, threads, frag):
     if Path(f"{outdir}/genbank/bacteria").is_dir():
         count = len(list(Path(f"{outdir}/genbank/bacteria").glob("*")))
         print(f"\n\n{count} genomes of {genus} were downloaded")
+        return count
     else:
         raise Exception(f"Download failed because {genus} is invalid or there are no records of the requested type in NCBI\n\n")
-
-
-
-    
-
-
+        return
\ No newline at end of file
